# Sage - Abstract Algebra: Theory and Applications

This package was designed as part of a Project at Southern Utah University.  The original project can be found at
[Github](https://github.com/bradencarlson/sage-jupyter) and was originally written in SageMath in Jupyter Notebooks.

The original project was designed to be used in Jupyter Notebooks, but this package was later created for those who wish to 
easily use the functions in this project from a Sage Terminal.  

Note that most (if not all) of this project will not run in Python alone, but rather must be run in SageMath.
